.. include:: ../README.md
   :parser: markdown

Contents:
=========

.. toctree::
   :maxdepth: 2

   installation
   usage
   tutorial
   faq
   galsbi
   modules
   contributing
   authors
   history

Feedback
========

If you have any suggestions or questions about **galsbi** feel free to email me
at silvanf@phys.ethz.ch.

If you encounter any errors or problems with **galsbi**, please let me know!


Code Coverage Report
====================

`html report <./htmlcov/index.html>`_
